@@ -8,12 +8,14 @@ if __name__ == '__main__':
     from1 = From('{{dataset.A}}')
     from2 = From('{{dataset.B}}')
     from3 = From('{{dataset.C}}')
-    condition1 = Condition(field3, "NEXT")
-    condition2 = Condition(field3, "LOE", ["{{timePeriod.B}}"])
-    condition3 = Condition(field1, "EQ", [2000])
+    field4 = Field(column="{{unknownDateDimension.A}}")
+    condition1 = Condition(field4, "FROM", direction="NEXT", steps="{{number.A}}", interval="{{timeDimension.B}}")
+    condition2 = Condition(field1, "LOE", ["{{number.B}}"])
+    condition3 = Condition(field2, "IN", ["{{entity.A}}"])
+    condition4 = Condition(field4, "RANGE", value=["{{timePeriodStart.A}}"], vuntil=["{{timePeriodEnd.A}}"])
     sorting1 = Sorting("{{measure.A}}", SQLSorting.DESC)
     component = ChartComponent(type='chart', queryId="0", chartType='LINE')
-    query1 = Query(fields=[field1, field2, field3], datasets=[from1, from2, from3], where=[condition1, condition2, condition3],
+    query1 = Query(fields=[field1, field2, field3], datasets=[from1, from2, from3], where=[condition1, condition2, condition3, condition4],
                    orderBy=[sorting1], limit=10)
     smartquery = SmartQuery(queries=[query1], components=[component])
     dump = jsons.dumps(smartquery)
